@@ -50,24 +50,37 @@
 #' 
 bindPosterior <- function(hydePost, relabel_factor=TRUE){
 
-  #* first, bind chains within an mcmc object together
-  bind_chains <- function(mcmc){
-    m <- lapply(mcmc, as.data.frame)
-    dplyr::bind_rows(m)
-  }
-  
   if (class(hydePost$codas) == "mcmc.list")
-    bound <- dplyr::bind_rows(lapply(hydePost$codas, as.data.frame))
+    bound <- dplyr::bind_rows(lapply(seq_along(hydePost$codas), bind_chains_mcmclist, hydePost))
   else 
-    bound <- dplyr::bind_rows(lapply(hydePost$codas, bind_chains))
+    bound <- dplyr::bind_rows(lapply(hydePost$codas, bind_chains_list))
   
-  factors_to_relabel <- names(bound)[names(bound) %in% names(hydePost$factorRef)]
-  
-  for(i in factors_to_relabel){
-    bound[i] <- factor(bound[[i]], 
-                       levels=hydePost$factorRef[[i]]$value,
-                       labels=hydePost$factorRef[[i]]$label)
+  if (relabel_factor){
+    factors_to_relabel <- names(bound)[names(bound) %in% names(hydePost$factorRef)]
+    for(i in factors_to_relabel){
+      bound[i] <- factor(bound[[i]], 
+                         levels=hydePost$factorRef[[i]]$value,
+                         labels=hydePost$factorRef[[i]]$label)
+    }
   }
 
   as.data.frame(bound)
-}
\ No newline at end of file
+}
+
+
+
+#**** UTILITY FUNCTIONS
+bind_chains_mcmclist <- function(mcmc, hydePost){
+  as.data.frame(hydePost$codas[[mcmc]]) %>%
+    dplyr::mutate_(chain_index = ~mcmc,
+            obs_index = ~1:n())
+}
+
+bind_chains_list <- function(mcmc){
+  lapply(1:length(mcmc),
+         function(chain)
+           as.data.frame(mcmc[[chain]]) %>%
+             dplyr::mutate_(chain_index = ~chain,
+                     obs_index = ~1:n())) %>%
+    dplyr::bind_rows()
+}
